@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for cloud9 service client
 
@@ -7,16 +8,15 @@ Usage::
     import boto3
     from mypy_boto3_cloud9 import Cloud9Client
 
-    session = boto3.Session()
-
     client: Cloud9Client = boto3.client("cloud9")
-    session_client: Cloud9Client = session.client("cloud9")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_cloud9.paginator import (
     DescribeEnvironmentMembershipsPaginator,
     ListEnvironmentsPaginator,
@@ -25,8 +25,8 @@ from mypy_boto3_cloud9.type_defs import (
     CreateEnvironmentEC2ResultTypeDef,
     CreateEnvironmentMembershipResultTypeDef,
     DescribeEnvironmentMembershipsResultTypeDef,
-    DescribeEnvironmentStatusResultTypeDef,
     DescribeEnvironmentsResultTypeDef,
+    DescribeEnvironmentStatusResultTypeDef,
     ListEnvironmentsResultTypeDef,
     ListTagsForResourceResponseTypeDef,
     TagTypeDef,
@@ -183,3 +183,6 @@ class Cloud9Client:
         """
         [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
