@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for cloud9 service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_cloud9 import Cloud9Client
-    from mypy_boto3_cloud9 import (
+    from mypy_boto3_cloud9.paginator import (
         DescribeEnvironmentMembershipsPaginator,
         ListEnvironmentsPaginator,
     )
@@ -18,10 +19,11 @@ Usage::
     list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_cloud9.type_defs import (
     DescribeEnvironmentMembershipsResultTypeDef,
     ListEnvironmentsResultTypeDef,
